Event Severity
==============

The :class:`Severity` class is used to define the severity of a log event.
This enum can only be used in the context of a log ingestion when calling
the :meth:`dynatrace_extension.Extension.report_event` method.

Members
^^^^^^^

.. autoclass:: dynatrace_extension.Severity
   :members:
   :undoc-members:
